@@ -74,8 +74,9 @@ class TerncyZCListener(object):
 
 
 class Terncy:
-    def __init__(self, client_id, ip, port=443, username="", token=""):
+    def __init__(self, client_id, dev_id, ip, port=443, username="", token=""):
         self.client_id = client_id
+        self.dev_id = dev_id
         self.ip = ip
         self.port = port
         self.username = username
@@ -251,6 +252,7 @@ class Terncy:
             aiohttp.client_exceptions.ClientConnectionError,
             websockets.exceptions.ConnectionClosedError,
             ConnectionRefusedError,
+            OSError,
             websockets.exceptions.InvalidStatusCode,
         ) as e:
             print("failed to connect server:", datetime.now())
